/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: GetOperationsMBeanCommand.as 5199 2009-09-29 13:44:05Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.console.jmxbrowser.command {


import com.adobe.cairngorm.commands.ICommand;
import com.adobe.cairngorm.control.CairngormEvent;

import mx.collections.ArrayCollection;
import mx.controls.Alert;
import mx.rpc.IResponder;
import mx.rpc.events.FaultEvent;
import mx.rpc.events.ResultEvent;

import org.ow2.easybeans.console.jmxbrowser.business.IOperationsFetchMBeanDelegate;
import org.ow2.easybeans.console.jmxbrowser.event.GetOperationsOfMBeanEvent;
import org.ow2.easybeans.console.jmxbrowser.model.JMXBrowerModelLocator;

/**
 * Command used to get all operations of an MBean
 * @author Florent Benoit
 */
public class GetOperationsMBeanCommand implements ICommand, IResponder {

    /**
     * Execute the action by asking the loading of XML data of MBeans.
     */
    public function execute(event : CairngormEvent) : void {

        // Event should be a GetOperationsOfMBeanEvent
        // cast it
        var getOperationsEvent : GetOperationsOfMBeanEvent = event as GetOperationsOfMBeanEvent;

        // Get MBean name
        var mbeanName : String = getOperationsEvent.mBeanName;

        // Fetch attributes
        var delegate : IOperationsFetchMBeanDelegate = JMXBrowerModelLocator.getInstance().getFetchOperationsDelegate();
        delegate.responder = this;
        delegate.getOperations(mbeanName);
    }

    /**
     * Manage the result found by a delegate.
     */
    public function result(event : Object) : void {

        // ArrayCollection value is contained in the event
        var resultEvent : ResultEvent = event as ResultEvent;
        // cast
        var arrayCollection : ArrayCollection = resultEvent.result as ArrayCollection;

        // Gets the Model
        var model : JMXBrowerModelLocator = JMXBrowerModelLocator.getInstance();

        // set attributes in the model
        model.selectedOperations = arrayCollection;
    }


    /**
     * Manage failure.
     */
    public function fault(event : Object) : void {
        var faultEvent : FaultEvent = FaultEvent(event);
        Alert.show("Error while fetching data !" + faultEvent);
    }

}
}

