/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: JMXBrowerModelLocator.as 5199 2009-09-29 13:44:05Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.console.jmxbrowser.model {

import com.adobe.cairngorm.model.IModelLocator;

import mx.collections.ArrayCollection;

import org.ow2.easybeans.console.jmxbrowser.business.AllMBeansDelegate;
import org.ow2.easybeans.console.jmxbrowser.business.AttributesFetchMBeanDelegate;
import org.ow2.easybeans.console.jmxbrowser.business.CallOperationMBeanDelegate;
import org.ow2.easybeans.console.jmxbrowser.business.IAllMBeansDelegate;
import org.ow2.easybeans.console.jmxbrowser.business.IAttributesFetchMBeanDelegate;
import org.ow2.easybeans.console.jmxbrowser.business.ICallOperationMBeanDelegate;
import org.ow2.easybeans.console.jmxbrowser.business.IOperationsFetchMBeanDelegate;
import org.ow2.easybeans.console.jmxbrowser.business.IUpdateAttributeMBeanDelegate;
import org.ow2.easybeans.console.jmxbrowser.business.OperationsFetchMBeanDelegate;
import org.ow2.easybeans.console.jmxbrowser.business.UpdateAttributeMBeanDelegate;
import org.ow2.easybeans.console.jmxbrowser.locale.LocaleObject;

/**
 * Defines the model used in JMXBrowser.
 * @author Florent Benoit
 */
[Bindable]
public class JMXBrowerModelLocator implements IModelLocator {

    /**
     * The unique ID of this component
     *
     * @internal
     *   Used to prevent a Cairngorm issue: when a command event is dispatched,
     * every controller that registered this event type receives it, even if
     * located in another module. To prevent this from happening and triggering
     * multiple severe unexpected concurrence bugs, each event dispatched is
     * postfixed with this unique ID.
     */
    public var componentID : String = UIDUtil.createUID();

    /**
     * Unique instance of this model locator.
     */
    private static var unique : JMXBrowerModelLocator;

    /**
     * Link to the MBeans Delegate object.
     */
    private var mbeansDelegate : IAllMBeansDelegate;

    /**
     * Link to the MBeans attribute delegate object.
     */
    private var mbeansAttributeDelegate : IAttributesFetchMBeanDelegate;


    /**
     * Link to the MBeans operations delegate object.
     */
    private var mbeansOperationsDelegate : IOperationsFetchMBeanDelegate;

    /**
     * Link to the MBeans update attribute delegate object.
     */
    private var mbeansUpdateAttributeDelegate : IUpdateAttributeMBeanDelegate;

    /**
     * Link to the MBeans call operation delegate object.
     */
    private var mbeansCallOperationDelegate : ICallOperationMBeanDelegate;


    /**
     * Attributes of the selected element.
     */
    [ArrayElementType(JMXAttributeVO)]
    public var selectedAttributes : ArrayCollection;


    /**
     * Operations of the selected element.
     */
    [ArrayElementType(JMXOperationVO)]
    public var selectedOperations : ArrayCollection;

    /**
     * Link to the XML object representing all MBeans.
     */
    private var xml : XML;


    /**
     * Value of the selected MBean.
     */
    private var selectedMBeanText : String;

    /**
     * Object managing locales.
     */
    private var localeObject : LocaleObject;

    /**
     * Constructor shouldn't be public but AS3 doesn't allow this.
     */
    public function JMXBrowerModelLocator() {
        super();

        if (unique != null) {
            throw new Error("Only one instance of JMXBrowerModelLocator should be built with singleton pattern");
        }

        this.mbeansDelegate = new AllMBeansDelegate();
        this.mbeansAttributeDelegate = new AttributesFetchMBeanDelegate();
        this.mbeansOperationsDelegate = new OperationsFetchMBeanDelegate();
        this.mbeansUpdateAttributeDelegate = new UpdateAttributeMBeanDelegate();
        this.mbeansCallOperationDelegate = new CallOperationMBeanDelegate();
        this.localeObject = new LocaleObject();

    }

    /**
     * @return the unique instance of this model locator.
     */
    public static function getInstance() : JMXBrowerModelLocator {

        // Lazy initialization
        if (unique == null) {
            unique = new JMXBrowerModelLocator();
        }

        // return unique instance
        return unique;
    }


    /**
     *  Getter for retrieving the xml data object.
     * @return the XML object.
     */
    public function get xmlData() : XML {
        return xml;
    }

    /**
     * Setter for the XML value.
     * @param xml the given XML to set
     */
    public function set xmlData(xml : XML) : void {
        this.xml = xml;
    }


    /**
     *  Getter for retrieving the xml data object.
     * @return the XML object.
     */
    public function get selectedMBeanName() : String {
        return selectedMBeanText;
    }

    /**
     * Setter for the XML value.
     * @param xml the given XML to set
     */
    public function set selectedMBeanName(selectedMBeanText : String) : void {
        this.selectedMBeanText = selectedMBeanText;
    }

    /**
     * @return the Delegate object.
     */
    public function getMBeansDelegate() : IAllMBeansDelegate {
        return mbeansDelegate;
    }

    /**
     * @return the Delegate object.
     */
    public function getFetchAttributesDelegate() : IAttributesFetchMBeanDelegate {
        return mbeansAttributeDelegate;
    }

    /**
     * @return the Delegate object.
     */
    public function getFetchOperationsDelegate() : IOperationsFetchMBeanDelegate {
        return mbeansOperationsDelegate;
    }

    /**
     * @return the Delegate object.
     */
    public function getUpdateAttributeDelegate() : IUpdateAttributeMBeanDelegate {
        return mbeansUpdateAttributeDelegate;
    }

    /**
     * @return the Delegate object.
     */
    public function getCallOperationDelegate() : ICallOperationMBeanDelegate {
        return mbeansCallOperationDelegate;
    }

    public function get locale() : LocaleObject {
        return localeObject;
    }

    public function set locale(localeObject : LocaleObject) : void {
        this.localeObject = localeObject;
    }

}

}
