/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: CallOperationPopupClass.as 5199 2009-09-29 13:44:05Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.console.jmxbrowser.view {

import com.adobe.cairngorm.control.CairngormEventDispatcher;

import mx.containers.TitleWindow;
import mx.controls.ComboBox;
import mx.controls.NumericStepper;
import mx.controls.TextArea;
import mx.managers.PopUpManager;

import org.ow2.easybeans.console.jmxbrowser.event.CallOperationMBeanEvent;
import org.ow2.easybeans.console.jmxbrowser.model.JMXBrowerModelLocator;
import org.ow2.easybeans.console.jmxbrowser.vo.JMXOperationVO;
import org.ow2.easybeans.console.jmxbrowser.vo.JMXParameterOperationVO;

public class CallOperationPopupClass extends TitleWindow {

    public function CallOperationPopupClass() {
        super();
    }

    [Bindable]
    public var jmxOperation : JMXOperationVO;

    [Bindable]
    private var values : Array;

    [Bindable]
    [ArrayElementType(String)]
    private var signatures : Array;

    public var opener : Object;


    protected function call() : void {
        var callOperationEvent : CallOperationMBeanEvent = new CallOperationMBeanEvent(JMXBrowerModelLocator.getInstance().selectedMBeanName, jmxOperation.name, this.signatures, this.values);
        CairngormEventDispatcher.getInstance().dispatchEvent(callOperationEvent);
        close();
    }

    protected function close() : void {
        PopUpManager.removePopUp(this);
        returnFocus();
    }

    private function returnFocus() : void {
        opener.setFocus();
    }

    protected function creationComplete() : void {
        createComponents();
        PopUpManager.centerPopUp(this);
    }


    private function valueChanged(event : Event) : void {

        // Update value
        var target : Object = event.currentTarget;

        // get text attribute for textarea component
        if (target is TextArea) {
            // update the element of the values
            // id of target = index of array
            this.values[target.id] = event.currentTarget.text;
        }

        // use value for these
        if (target is ComboBox || target is NumericStepper) {
            // update the element of the values
            // id of target = index of array
            this.values[target.id] = event.currentTarget.value;
        }

    }


    private function createComponents() : void {

        // Create array for collections
        this.values = new Array(this.jmxOperation.parameters.length);
        this.signatures = new Array(this.jmxOperation.parameters.length);

        // Create elements for each parameter
        var item : int = 0;
        for each (var param : JMXParameterOperationVO in jmxOperation.parameters) {
            // Update signature
            signatures[item] = param.type;

            if ('boolean' == param.type) {
                var comboBox : ComboBox;
                comboBox = new ComboBox();
                comboBox.percentWidth = 80;
                comboBox.dataProvider = [false, true];
                comboBox.id = "" + item;
                comboBox.toolTip = param.name + ":" + param.desc;
                comboBox.addEventListener(Event.CHANGE, valueChanged);
                this.addChild(comboBox);
            } else if ('int' == param.type || 'long' == param.type) {
                var numericStepper : NumericStepper;
                numericStepper = new NumericStepper();
                numericStepper.percentWidth = 80;
                numericStepper.value = new Number(0);
                numericStepper.minimum = -999999;
                numericStepper.maximum = Number.MAX_VALUE;
                numericStepper.stepSize = 1;
                numericStepper.id = "" + item;
                numericStepper.toolTip = param.name + ":" + param.desc;
                numericStepper.addEventListener(Event.CHANGE, valueChanged);
                this.addChild(numericStepper);
                this.height = 200;
            } else if ('java.lang.String' == param.type) {
                var txtArea : TextArea;
                txtArea = new TextArea();
                txtArea.percentWidth = 80;
                txtArea.percentHeight = 80;
                txtArea.text = "";
                txtArea.id = "" + item;
                txtArea.toolTip = param.name + ":" + param.desc;
                txtArea.addEventListener(Event.CHANGE, valueChanged);
                this.addChild(txtArea);
            }
            item++;
        }
    }

}

}

