/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: CallOperationRendererClass.as 5199 2009-09-29 13:44:05Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.console.jmxbrowser.view {

import mx.containers.HBox;
import mx.controls.Button;
import mx.controls.dataGridClasses.DataGridListData;
import mx.controls.listClasses.BaseListData;
import mx.managers.PopUpManager;

import org.ow2.easybeans.console.jmxbrowser.model.JMXBrowerModelLocator;
import org.ow2.easybeans.console.jmxbrowser.vo.JMXOperationVO;
import org.ow2.easybeans.console.jmxbrowser.vo.JMXParameterOperationVO;

public class CallOperationRendererClass extends HBox {

    /**
     * Model used for the JMX Browser.
     */
    [Bindable]
    public var model : JMXBrowerModelLocator = JMXBrowerModelLocator.getInstance();

    /**
     * Call button.
     */
    [Bindable]
    public var callButton : Button;

    private var _listData : DataGridListData;

    [Bindable]
    public var jmxOperation : JMXOperationVO;

    private var pop : CallOperationPopup;


    public function CallOperationRendererClass() {
        super();
    }

    override public function set data(value : Object) : void {
        super.data = value;

        // Keep the value as JMX Operation
        this.jmxOperation = value as JMXOperationVO;

        // Update the text of the row with the given operation
        update();

    }

    override public function get data() : Object {
        return super.data;
    }

    public function get listData() : BaseListData {
        return _listData;
    }

    public function set listData(value : BaseListData) : void {
        _listData = DataGridListData(value);
    }

    // Adds the popup and set the jmxOperation on it
    private function openPopup() : void {
        pop = CallOperationPopup(PopUpManager.createPopUp(this.owner, CallOperationPopup, true));
        pop.jmxOperation = this.jmxOperation;
        pop.opener = this;
    }



    /**
     * Called when Tree selection is being changed.
     */
    public function clickButton(event : Event) : void {
        callLater(openPopup);
    }



    private function update() : void {
        // button not yet ready
        if (callButton == null) {
            return;
        }

        // Default is enabled
        callButton.enabled = true;


        // void method ?
        if (jmxOperation.returnType == "void") {
            callButton.toolTip = model.locale.getString('CALL_OPERATION_RENDERER_CALL_BUTTON_TOOLTIP', ["void"]);
        } else {
            callButton.toolTip = model.locale.getString('CALL_OPERATION_RENDERER_CALL_BUTTON_TOOLTIP', [""]);
        }

        // Check if all parameters are simple type else disable the button
        for each (var param : JMXParameterOperationVO in jmxOperation.parameters) {
            if ('java.lang.String' != param.type && 'int' != param.type && 'long' != param.type && 'boolean' != param.type) {
                callButton.enabled = false;
                callButton.toolTip = model.locale.getString('CALL_OPERATION_RENDERER_CALL_BUTTON_TOOLTIP_NOT_EDITABLE');
            }
        }
    }

}
}
