/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: DynamicPanel.as 5199 2009-09-29 13:44:05Z benoitf $
 * --------------------------------------------------------------------------
 */

 package org.ow2.easybeans.console.jmxbrowser.view {

    import flash.display.DisplayObject;
    import flash.events.Event;
    import flash.events.MouseEvent;
    
    import mx.containers.HBox;
    import mx.containers.Panel;
    import mx.controls.Button;
    import mx.controls.Spacer;
    import mx.effects.Resize;
    
    import org.ow2.easybeans.console.jmxbrowser.model.JMXBrowerModelLocator;
    

public class DynamicPanel extends Panel {

        /**
         * Model used for the JMX Browser.
         */
        [Bindable]
        public var model : JMXBrowerModelLocator = JMXBrowerModelLocator.getInstance();


        private var controlBox : HBox = null;
        private var minButton : Button = null;
        private var restoreButton : Button = null;
        private var maxButton : Button = null;

        private var originalWidth : int = 0;
        private var originalHeight : int = 0;

        [Embed(source='/../assets/images/button-min.png')]
        private var minIcon : Class;

        [Embed(source='/../assets/images/button-min-focus.png')]
        private var minFocusIcon : Class;

        [Embed(source='/../assets/images/button-min-inactive.png')]
        private var minDisabledIcon : Class;

        [Embed(source='/../assets/images/button-max.png')]
        private var maxIcon : Class;

        [Embed(source='/../assets/images/button-max-focus.png')]
        private var maxFocusIcon : Class;

        [Embed(source='/../assets/images/button-restore.png')]
        private var restoreIcon : Class;

        [Embed(source='/../assets/images/button-restore-focus.png')]
        private var restoreFocusIcon : Class;




        public function DynamicPanel() {
            super();
            // Add an event to be notified when locale is updated
            resourceManager.addEventListener(Event.CHANGE, updateLabels);
        }


        override protected function createChildren() : void {
            super.createChildren();

            if (!this.controlBox) {
                this.controlBox = new HBox();
                // Put controls on the right and vertical align to middle
                this.controlBox.setStyle("horizontalAlign", "right");
                this.controlBox.setStyle("verticalAlign", "middle");
                this.titleBar.addChild(controlBox);
            }

            if (!minButton) {
                minButton = new Button();
                minButton.setStyle("icon", this["minIcon"]);
                minButton.setStyle("upicon", this["minIcon"]);
                minButton.setStyle("overIcon", this["minFocusIcon"]);
                minButton.setStyle("disabledIcon", this["minDisabledIcon"]);
                minButton.height = 14;
                minButton.width = 30;
                minButton.addEventListener(MouseEvent.CLICK, minimize);
                controlBox.addChild(minButton);
            }

            if (!restoreButton) {
                restoreButton = new Button();
                restoreButton.setStyle("icon", this["restoreIcon"]);
                restoreButton.setStyle("upicon", this["restoreIcon"]);
                restoreButton.setStyle("overIcon", this["restoreFocusIcon"]);
                restoreButton.height = 14;
                restoreButton.width = 30;
                restoreButton.visible = false;
                restoreButton.includeInLayout = restoreButton.visible;

                restoreButton.addEventListener(MouseEvent.CLICK, restore);
                controlBox.addChild(restoreButton);
            }

            if (!maxButton) {
                maxButton = new Button();
                maxButton.setStyle("icon", this["maxIcon"]);
                maxButton.setStyle("upicon", this["maxIcon"]);
                maxButton.setStyle("overIcon", this["maxFocusIcon"]);
                maxButton.height = 14;

                maxButton.width = 30;
                maxButton.addEventListener(MouseEvent.CLICK, maximize);
                controlBox.addChild(maxButton);
            }

            // Configure labels
            updateLabels(null);
        }

        private function keepSize() : void {
             // store the original size
            if (originalWidth == 0) {
                originalWidth = this.width;
            }
            if (originalHeight == 0) {
                originalHeight = this.height;
            }

        }

    private function updateLabels(event : Event) : void {
        if (maxButton != null) {
            maxButton.label = model.locale.getString("JMX_PANEL_MAXIMIZE");
        }
        if (minButton != null) {
            minButton.label = model.locale.getString("JMX_PANEL_MINIMIZE");
        }
        if (restoreButton != null) {
            restoreButton.label = model.locale.getString("JMX_PANEL_RESTORE");
        }

    }


        private function minimize(event:MouseEvent):void {
            keepSize();

            var resize : Resize = new Resize();
            resize.target = this;
            resize.duration = 300;
            resize.heightTo = 30;
            //resize.widthTo = 200;
            resize.end();
            resize.play();
            minButton.enabled = false;
            minButton.visible = false;
            restoreButton.enabled = true;
            restoreButton.visible = true;
            restoreButton.includeInLayout = true;
            maxButton.enabled = true;
            maxButton.visible = true;
            maxButton.includeInLayout = true;

    }

        private function restore(event:MouseEvent):void {
            keepSize();

            var resize : Resize = new Resize();
            resize.target = this;
            resize.duration = 300;
            resize.heightTo = originalHeight;
            //resize.widthTo = originalWidth;
            resize.end();
            resize.play();
            restoreButton.enabled = false;
            restoreButton.visible = false;
            restoreButton.includeInLayout = false;
            minButton.enabled = true;
            minButton.visible = true;
            maxButton.enabled = true;
            maxButton.visible = true;
            maxButton.includeInLayout = true;

    }

        private function maximize(event:MouseEvent):void {
            keepSize();


            var resize : Resize = new Resize();
            resize.target = this;
            resize.duration = 300;

            // height of components with same parent
            var numChildren : int = parent.numChildren;
            var brothersHeight : int = 0;
            for (var i:int = 0; i < numChildren; i++) {
                var obj : DisplayObject = parent.getChildAt(i);
                if (this == obj || obj is Spacer) {
                    continue;
                }
                brothersHeight += obj.height;
            }

            resize.heightTo = this.parent.height - brothersHeight  - 30;
            //resize.widthTo = originalWidth;
            resize.end();
            resize.play();
            maxButton.enabled = false;
            maxButton.visible = false;
            maxButton.includeInLayout = false;
            restoreButton.enabled = true;
            restoreButton.visible = true;
            restoreButton.includeInLayout = true;
            minButton.enabled = true;
            minButton.visible = true;

    }


    override protected function updateDisplayList(unscaledWidth:Number, unscaledHeight:Number):void
    {
        super.updateDisplayList(unscaledWidth, unscaledHeight);

        // update control box
        this.controlBox.y = titleBar.y;
        this.controlBox.width = unscaledWidth;
        this.controlBox.height = titleBar.height;



    }


    }
}
