/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: EditAttributePopupClass.as 5199 2009-09-29 13:44:05Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.console.jmxbrowser.view  {

    import com.adobe.cairngorm.control.CairngormEventDispatcher;

    import mx.containers.TitleWindow;
    import mx.controls.Button;
    import mx.controls.ComboBox;
    import mx.controls.NumericStepper;
    import mx.controls.TextArea;
    import mx.managers.PopUpManager;

    import org.ow2.easybeans.console.jmxbrowser.event.UpdateAttributeOfMBeanEvent;
    import org.ow2.easybeans.console.jmxbrowser.model.JMXBrowerModelLocator;
    import org.ow2.easybeans.console.jmxbrowser.vo.JMXAttributeVO;

    public class EditAttributePopupClass extends TitleWindow {


        /**
         * Model used for the JMX Browser.
         */
        [Bindable]
        public var model : JMXBrowerModelLocator = JMXBrowerModelLocator.getInstance();


            /**
             * Apply button.
             */
            [Bindable]
            public var buttonApply : Button;


            [Bindable]
            public var jmxAttributes:JMXAttributeVO;

            private var newValue:Object;

            public var opener:Object;


            public function EditAttributePopupClass() {
                super();
            }

            protected function apply():void{
                var updateAttributeEvent : UpdateAttributeOfMBeanEvent = new UpdateAttributeOfMBeanEvent(JMXBrowerModelLocator.getInstance().selectedMBeanName, jmxAttributes.name, this.newValue);
                CairngormEventDispatcher.getInstance().dispatchEvent(updateAttributeEvent);
                close();
            }

            protected function close():void{
                PopUpManager.removePopUp(this);
                returnFocus();
            }

            private function returnFocus():void{
                opener.setFocus();
            }

            protected function creationComplete():void{
                createComponents();
                PopUpManager.centerPopUp(this);
                //ta.setFocus();
            }


            protected function valueChanged(event : Event): void {
                // Update value
                var target : Object = event.currentTarget;

                // get text attribute for textarea component
                if (target is TextArea) {
                    this.newValue = event.currentTarget.text;
                }
                // use value for these
                if (target is ComboBox || target is NumericStepper) {
                    this.newValue = event.currentTarget.value;
                }

            }




     private function createComponents():void
  {

      // type is boolean ?
      if ('boolean' == this.jmxAttributes.type) {
          var comboBox: ComboBox;
          comboBox = new ComboBox();
          comboBox.percentWidth = 80;
          comboBox.dataProvider = [ false, true];

          if ("false" == jmxAttributes.value) {
            comboBox.selectedIndex = 0;
          } else {
              comboBox.selectedIndex = 1;
          }
          comboBox.addEventListener(Event.CHANGE, valueChanged);
          this.addChild(comboBox);
          this.height = 200;
      } else if ('int' ==  this.jmxAttributes.type || 'long' ==  this.jmxAttributes.type) {
          var numericStepper: NumericStepper;
          numericStepper = new NumericStepper();
          numericStepper.percentWidth = 80;
          numericStepper.value = new Number(this.jmxAttributes.value);
          numericStepper.minimum = -999999;
          numericStepper.maximum = Number.MAX_VALUE;
          numericStepper.stepSize=1;
          numericStepper.addEventListener(Event.CHANGE, valueChanged);
          this.addChild(numericStepper);
          this.height = 200;
      } else if ('java.lang.String' ==  this.jmxAttributes.type) {
          var txtArea  : TextArea;
          txtArea = new TextArea();
          txtArea.percentWidth = 80;
          txtArea.percentHeight = 80;
          txtArea.text = this.jmxAttributes.value;
          txtArea.addEventListener(Event.CHANGE, valueChanged);
          this.addChild(txtArea);
      }
  }



    }
}
